==> haskell-monad-time-0.3.1.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-time
version:              0.3.1.0
visibility:           public
id:                   monad-time-0.3.1.0-4tLFe4CV0BOLalyGkEzbQ3
key:                  monad-time-0.3.1.0-4tLFe4CV0BOLalyGkEzbQ3
license:              BSD-3-Clause
copyright:            Scrive AB
maintainer:
    Andrzej Rybczak <andrzej@rybczak.net>,
    Jonathan Jouty <jonathan@scrive.com>,
    Mikhail Glushenkov <mikhail@scrive.com>

author:               Andrzej Rybczak
homepage:             https://github.com/scrive/monad-time
synopsis:
    Type class for monads which carry
    the notion of the current time.

description:
    '\''MonadTime'\'' type class for monads
    which carry the notion of the current time.

category:             Control
abi:                  1efcba970221a77b68cebbfc0e800358
exposed:              True
exposed-modules:      Control.Monad.Time
import-dirs:          /usr/lib/ghc-9.0.1/site-local/monad-time-0.3.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/monad-time-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/monad-time-0.3.1.0
hs-libraries:         HSmonad-time-0.3.1.0-4tLFe4CV0BOLalyGkEzbQ3
depends:              base-4.15.0.0 mtl-2.2.2 time-1.9.3
haddock-interfaces:   /usr/share/doc/haskell-monad-time/html/monad-time.haddock
haddock-html:         /usr/share/doc/haskell-monad-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-time-0.4.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-time
version:              0.4.0.0
visibility:           public
id:                   monad-time-0.4.0.0-85n5Y4sAC912T5q7IVV2id
key:                  monad-time-0.4.0.0-85n5Y4sAC912T5q7IVV2id
license:              BSD-3-Clause
copyright:            Scrive AB
maintainer:
    Andrzej Rybczak <andrzej@rybczak.net>,
    Jonathan Jouty <jonathan@scrive.com>,
    Mikhail Glushenkov <mikhail@scrive.com>

author:               Andrzej Rybczak
homepage:             https://github.com/scrive/monad-time
synopsis:
    Type class for monads which carry
    the notion of the current time.

description:
    '\''MonadTime'\'' type class for monads
    which carry the notion of the current time.

category:             Control
abi:                  e17170da7bf35f0f7c82ab2a4f4612aa
exposed:              True
exposed-modules:      Control.Monad.Time
import-dirs:          /usr/lib/ghc-9.0.2/site-local/monad-time-0.4.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monad-time-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-time
hs-libraries:         HSmonad-time-0.4.0.0-85n5Y4sAC912T5q7IVV2id
depends:              base-4.15.1.0 mtl-2.2.2 time-1.9.3
haddock-interfaces:   /usr/share/doc/haskell-monad-time/html/monad-time.haddock
haddock-html:         /usr/share/doc/haskell-monad-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
